Stan Math Library: stan/math/prim/scal/meta/is_var.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_var.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_IS_VAR_HPP
2 #define STAN_MATH_PRIM_SCAL_META_IS_VAR_HPP
3
4 namespace stan {
5
6 template <typename T>
7 struct is_var {
8 enum { value = false };
9 };
10
11 }
12 #endif
13
stan::is_var::value
Definition: is_var.hpp:8
stan
Definition: log_sum_exp.hpp:8
stan::is_var
Definition: is_var.hpp:7

[ Stan Home Page ] © 2011–2016, Stan Development Team.